@@ -264,7 +264,6 @@ yelp_application_startup (GApplication *application)
 {
     YelpApplication *app = YELP_APPLICATION (application);
     YelpApplicationPrivate *priv = GET_PRIV (app);
-    GMenu *menu, *section;
     gchar *keyfile;
     YelpSettings *settings;
 
@@ -315,18 +314,6 @@ yelp_application_startup (GApplication *application)
     g_action_map_add_action (G_ACTION_MAP (app), G_ACTION (priv->smaller_text_action));
 
     application_set_font_sensitivity (app);
-
-    menu = g_menu_new ();
-    section = g_menu_new ();
-    g_menu_append (section, _("New Window"), "win.yelp-window-new");
-    g_menu_append_section (menu, NULL, G_MENU_MODEL (section));
-    g_object_unref (section);
-    section = g_menu_new ();
-    g_menu_append (section, _("Larger Text"), "app.yelp-application-larger-text");
-    g_menu_append (section, _("Smaller Text"), "app.yelp-application-smaller-text");
-    g_menu_append_section (menu, NULL, G_MENU_MODEL (section));
-    g_object_unref (section);
-    gtk_application_set_app_menu (GTK_APPLICATION (application), G_MENU_MODEL (menu));
 }
 
 /******************************************************************************/
@@ -370,12 +357,30 @@ YelpApplication *
 yelp_application_new (void)
 {
     YelpApplication *app;
+    char *app_id = NULL;
+    char *yelp = NULL;
+
+    if (g_file_test ("/.flatpak-info", G_FILE_TEST_EXISTS)) {
+        GKeyFile *kf = g_key_file_new ();
+        g_key_file_load_from_file (kf, "/.flatpak-info", G_KEY_FILE_NONE, NULL);
+        if (g_key_file_has_group (kf, "Application"))
+          app_id = g_key_file_get_string (kf, "Application", "name", NULL);
+        else
+          app_id = g_key_file_get_string (kf, "Runtime", "name", NULL);
+        yelp = g_strconcat (app_id, ".Help", NULL);
+        g_key_file_unref (kf);
+    }
+    else {
+        yelp = g_strdup ("org.gnome.Yelp");
+    }
 
     app = g_object_new (YELP_TYPE_APPLICATION,
-                        "application-id", "org.gnome.Yelp",
+                        "application-id", yelp,
                         "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
                         "inactivity-timeout", 5000,
                         NULL);
+    g_free (app_id);
+    g_free (yelp);
 
     return app;
 }
